# PyJaegerTracing

PyJaegerTracing: Ultimate tool for distribution tracing in Python


## Installation

```bash
pip install py-jaeger-tracing
```


## Features

* Multiprocessing support
* Context / Decorator based tracing
* Injecting / Extracting tracer span
* Logger integration
* Requests integration using patching
* Boto3 integration using patching
* Tornado integration
